==> ah-formbuilder-1.0.61.tgz: package/es/utils/inputs/TextInput.js <==
import React from 'react';
import { makeStyles } from '@material-ui/core/styles';
import FormControl from "@material-ui/core/FormControl";
import Input from "@material-ui/core/Input";
import InputAdornment from "@material-ui/core/InputAdornment";
import FormHelperText from "@material-ui/core/FormHelperText";
import InputLabel from "@material-ui/core/InputLabel";
var useStyles = makeStyles(function (theme) {
  return {
    labelRoot: {
      transform: 'none'
    }
  };
});

var TextInput = function TextInput(props) {
  var value = props.value,
      handleChange = props.handleChange,
      required = props.required,
      inputProps = props.inputProps,
      helperText = props.helperText,
      error = props.error,
      startAdornment = props.startAdornment,
      endAdornment = props.endAdornment,
      label = props.label,
      placeholder = props.placeholder,
      disabled = props.disabled,
      autoFocus = props.autoFocus,
      type = props.type;
  var classes = useStyles();
  return /*#__PURE__*/React.createElement(FormControl, {
    required: required,
    disabled: disabled,
    error: !!error,
    fullWidth: true
  }, label ? /*#__PURE__*/React.createElement(InputLabel, {
    required: required,
    shrink: true,
    classes: {
      shrink: classes.labelRoot
    }
  }, label) : "", /*#__PURE__*/React.createElement(Input, {
    autoFocus: !!autoFocus,
    placeholder: placeholder,
    value: value,
    onChange: handleChange,
    startAdornment: startAdornment ? /*#__PURE__*/React.createElement(InputAdornment, {
      position: "start"
    }, startAdornment) : null,
    endAdornment: endAdornment ? /*#__PURE__*/React.createElement(InputAdornment, {
      position: "end"
    }, endAdornment) : null,
    inputProps: inputProps,
    type: type ? type : 'text',
    onBlur: props.onBlur,
    classes: {
      root: classes.inputRoot
    }
  }), helperText ? /*#__PURE__*/React.createElement(FormHelperText, null, helperText) : "", !!error ? /*#__PURE__*/React.createElement(FormHelperText, {
    error: true
  }, error) : "");
};

export default TextInput;

==> ah-formbuilder-1.0.92.tgz: package/es/utils/inputs/TextInput.js <==
var _this = this,
    _jsxFileName = "/home/zaman/Documents/GitLab/bayt/formbuilder/src/utils/inputs/TextInput.js";

import React from 'react';
import { makeStyles } from '@material-ui/core/styles';
import FormControl from "@material-ui/core/FormControl";
import Input from "@material-ui/core/Input";
import InputAdornment from "@material-ui/core/InputAdornment";
import FormHelperText from "@material-ui/core/FormHelperText";
import InputLabel from "@material-ui/core/InputLabel";
var useStyles = makeStyles(function (theme) {
  return {
    labelRoot: {
      transform: 'none'
    }
  };
});

var TextInput = function TextInput(props) {
  var value = props.value,
      handleChange = props.handleChange,
      required = props.required,
      inputProps = props.inputProps,
      helperText = props.helperText,
      error = props.error,
      startAdornment = props.startAdornment,
      endAdornment = props.endAdornment,
      label = props.label,
      placeholder = props.placeholder,
      disabled = props.disabled,
      autoFocus = props.autoFocus,
      type = props.type;
  var classes = useStyles();
  return /*#__PURE__*/React.createElement(FormControl, {
    required: required,
    disabled: disabled,
    error: !!error,
    fullWidth: true,
    __self: _this,
    __source: {
      fileName: _jsxFileName,
      lineNumber: 21,
      columnNumber: 5
    }
  }, label ? /*#__PURE__*/React.createElement(InputLabel, {
    required: required,
    shrink: true,
    classes: {
      shrink: classes.labelRoot
    },
    __self: _this,
    __source: {
      fileName: _jsxFileName,
      lineNumber: 23,
      columnNumber: 9
    }
  }, label) : "", /*#__PURE__*/React.createElement(Input, {
    autoFocus: !!autoFocus,
    placeholder: placeholder,
    value: value,
    onChange: handleChange,
    startAdornment: startAdornment ? /*#__PURE__*/React.createElement(InputAdornment, {
      position: "start",
      __self: _this,
      __source: {
        fileName: _jsxFileName,
        lineNumber: 30,
        columnNumber: 45
      }
    }, startAdornment) : null,
    endAdornment: endAdornment ? /*#__PURE__*/React.createElement(InputAdornment, {
      position: "end",
      __self: _this,
      __source: {
        fileName: _jsxFileName,
        lineNumber: 31,
        columnNumber: 41
      }
    }, endAdornment) : null,
    inputProps: inputProps,
    type: type ? type : 'text',
    onBlur: props.onBlur,
    classes: {
      root: classes.inputRoot
    },
    __self: _this,
    __source: {
      fileName: _jsxFileName,
      lineNumber: 25,
      columnNumber: 7
    }
  }), helperText ? /*#__PURE__*/React.createElement(FormHelperText, {
    __self: _this,
    __source: {
      fileName: _jsxFileName,
      lineNumber: 38,
      columnNumber: 9
    }
  }, helperText) : "", !!error ? /*#__PURE__*/React.createElement(FormHelperText, {
    error: true,
    __self: _this,
    __source: {
      fileName: _jsxFileName,
      lineNumber: 41,
      columnNumber: 9
    }
  }, error) : "");
};

export default TextInput;
